# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '.\ui_Plotter.ui'
#
# Created by: PyQt5 UI code generator 5.12
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1208, 911)
        MainWindow.setStyleSheet("background-color: rgb(255, 255, 255);")
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setAutoFillBackground(False)
        self.centralwidget.setObjectName("centralwidget")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.centralwidget)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
        self.verticalLayout.setObjectName("verticalLayout")
        spacerItem = QtWidgets.QSpacerItem(1000, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout.addItem(spacerItem)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem1)
        self.horizontalLayout_4.addLayout(self.verticalLayout)
        self.groupBox = QtWidgets.QGroupBox(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setMaximumSize(QtCore.QSize(600, 16777215))
        self.groupBox.setBaseSize(QtCore.QSize(300, 0))
        self.groupBox.setTitle("")
        self.groupBox.setFlat(False)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_5.setSizeConstraint(QtWidgets.QLayout.SetNoConstraint)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.toolBox = QtWidgets.QToolBox(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.toolBox.sizePolicy().hasHeightForWidth())
        self.toolBox.setSizePolicy(sizePolicy)
        self.toolBox.setMinimumSize(QtCore.QSize(200, 0))
        self.toolBox.setMaximumSize(QtCore.QSize(300, 16777215))
        self.toolBox.setBaseSize(QtCore.QSize(100, 0))
        self.toolBox.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.toolBox.setObjectName("toolBox")
        self.FigureParameters = QtWidgets.QWidget()
        self.FigureParameters.setGeometry(QtCore.QRect(0, 0, 200, 610))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.FigureParameters.sizePolicy().hasHeightForWidth())
        self.FigureParameters.setSizePolicy(sizePolicy)
        self.FigureParameters.setObjectName("FigureParameters")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.FigureParameters)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_10 = QtWidgets.QLabel(self.FigureParameters)
        self.label_10.setObjectName("label_10")
        self.gridLayout_2.addWidget(self.label_10, 2, 0, 1, 1)
        self.spinBoxFigureDPI = QtWidgets.QSpinBox(self.FigureParameters)
        self.spinBoxFigureDPI.setMinimum(10)
        self.spinBoxFigureDPI.setMaximum(100000000)
        self.spinBoxFigureDPI.setSingleStep(100)
        self.spinBoxFigureDPI.setProperty("value", 100)
        self.spinBoxFigureDPI.setObjectName("spinBoxFigureDPI")
        self.gridLayout_2.addWidget(self.spinBoxFigureDPI, 1, 0, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem2, 8, 0, 1, 1)
        self.label_9 = QtWidgets.QLabel(self.FigureParameters)
        self.label_9.setObjectName("label_9")
        self.gridLayout_2.addWidget(self.label_9, 0, 0, 1, 1)
        self.spinBoxFigureSavedDPI = QtWidgets.QSpinBox(self.FigureParameters)
        self.spinBoxFigureSavedDPI.setMinimum(10)
        self.spinBoxFigureSavedDPI.setMaximum(100000000)
        self.spinBoxFigureSavedDPI.setSingleStep(100)
        self.spinBoxFigureSavedDPI.setProperty("value", 100)
        self.spinBoxFigureSavedDPI.setObjectName("spinBoxFigureSavedDPI")
        self.gridLayout_2.addWidget(self.spinBoxFigureSavedDPI, 3, 0, 1, 1)
        self.frame = QtWidgets.QFrame(self.FigureParameters)
        self.frame.setFrameShape(QtWidgets.QFrame.Box)
        self.frame.setFrameShadow(QtWidgets.QFrame.Plain)
        self.frame.setObjectName("frame")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.frame)
        self.verticalLayout_4.setContentsMargins(1, 1, 1, 1)
        self.verticalLayout_4.setSpacing(2)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.label_11 = QtWidgets.QLabel(self.frame)
        self.label_11.setObjectName("label_11")
        self.verticalLayout_4.addWidget(self.label_11)
        self.label_12 = QtWidgets.QLabel(self.frame)
        self.label_12.setObjectName("label_12")
        self.verticalLayout_4.addWidget(self.label_12)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setContentsMargins(5, 5, 5, 5)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.spinBoxFigSizeWidth = QtWidgets.QDoubleSpinBox(self.frame)
        self.spinBoxFigSizeWidth.setMaximum(100.0)
        self.spinBoxFigSizeWidth.setObjectName("spinBoxFigSizeWidth")
        self.horizontalLayout_3.addWidget(self.spinBoxFigSizeWidth)
        self.spinBoxFigSizeHeight = QtWidgets.QDoubleSpinBox(self.frame)
        self.spinBoxFigSizeHeight.setMaximum(100.0)
        self.spinBoxFigSizeHeight.setObjectName("spinBoxFigSizeHeight")
        self.horizontalLayout_3.addWidget(self.spinBoxFigSizeHeight)
        self.verticalLayout_4.addLayout(self.horizontalLayout_3)
        self.gridLayout_2.addWidget(self.frame, 4, 0, 1, 1)
        self.pushButtonApplyFigParams = QtWidgets.QPushButton(self.FigureParameters)
        self.pushButtonApplyFigParams.setObjectName("pushButtonApplyFigParams")
        self.gridLayout_2.addWidget(self.pushButtonApplyFigParams, 5, 0, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem3, 6, 0, 1, 1)
        self.toolBox.addItem(self.FigureParameters, "")
        self.AxisParameters = QtWidgets.QWidget()
        self.AxisParameters.setGeometry(QtCore.QRect(0, 0, 200, 610))
        self.AxisParameters.setObjectName("AxisParameters")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.AxisParameters)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.label_5 = QtWidgets.QLabel(self.AxisParameters)
        self.label_5.setObjectName("label_5")
        self.verticalLayout_3.addWidget(self.label_5)
        self.checkBoxAxisVisible = QtWidgets.QCheckBox(self.AxisParameters)
        self.checkBoxAxisVisible.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBoxAxisVisible.setText("")
        self.checkBoxAxisVisible.setChecked(True)
        self.checkBoxAxisVisible.setObjectName("checkBoxAxisVisible")
        self.verticalLayout_3.addWidget(self.checkBoxAxisVisible)
        self.label_6 = QtWidgets.QLabel(self.AxisParameters)
        self.label_6.setObjectName("label_6")
        self.verticalLayout_3.addWidget(self.label_6)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setContentsMargins(-1, -1, -1, 10)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.lineEditXLimMin = QtWidgets.QLineEdit(self.AxisParameters)
        self.lineEditXLimMin.setObjectName("lineEditXLimMin")
        self.horizontalLayout.addWidget(self.lineEditXLimMin)
        self.lineEditXLimMax = QtWidgets.QLineEdit(self.AxisParameters)
        self.lineEditXLimMax.setObjectName("lineEditXLimMax")
        self.horizontalLayout.addWidget(self.lineEditXLimMax)
        self.verticalLayout_3.addLayout(self.horizontalLayout)
        self.label_7 = QtWidgets.QLabel(self.AxisParameters)
        self.label_7.setObjectName("label_7")
        self.verticalLayout_3.addWidget(self.label_7)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setContentsMargins(-1, -1, -1, 10)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.lineEditYLimMin = QtWidgets.QLineEdit(self.AxisParameters)
        self.lineEditYLimMin.setObjectName("lineEditYLimMin")
        self.horizontalLayout_2.addWidget(self.lineEditYLimMin)
        self.lineEditYLimMax = QtWidgets.QLineEdit(self.AxisParameters)
        self.lineEditYLimMax.setObjectName("lineEditYLimMax")
        self.horizontalLayout_2.addWidget(self.lineEditYLimMax)
        self.verticalLayout_3.addLayout(self.horizontalLayout_2)
        self.label_8 = QtWidgets.QLabel(self.AxisParameters)
        self.label_8.setObjectName("label_8")
        self.verticalLayout_3.addWidget(self.label_8)
        self.comboBoxAxisScaling = QtWidgets.QComboBox(self.AxisParameters)
        self.comboBoxAxisScaling.setObjectName("comboBoxAxisScaling")
        self.comboBoxAxisScaling.addItem("")
        self.comboBoxAxisScaling.addItem("")
        self.comboBoxAxisScaling.addItem("")
        self.comboBoxAxisScaling.addItem("")
        self.comboBoxAxisScaling.addItem("")
        self.verticalLayout_3.addWidget(self.comboBoxAxisScaling)
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem4)
        self.gridLayout_3.addLayout(self.verticalLayout_3, 1, 0, 1, 1)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setContentsMargins(10, 10, 10, 10)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label = QtWidgets.QLabel(self.AxisParameters)
        self.label.setObjectName("label")
        self.verticalLayout_2.addWidget(self.label)
        self.lineEditTitle = QtWidgets.QLineEdit(self.AxisParameters)
        self.lineEditTitle.setObjectName("lineEditTitle")
        self.verticalLayout_2.addWidget(self.lineEditTitle)
        self.label_2 = QtWidgets.QLabel(self.AxisParameters)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_2.addWidget(self.label_2)
        self.lineEditXLabel = QtWidgets.QLineEdit(self.AxisParameters)
        self.lineEditXLabel.setObjectName("lineEditXLabel")
        self.verticalLayout_2.addWidget(self.lineEditXLabel)
        self.label_3 = QtWidgets.QLabel(self.AxisParameters)
        self.label_3.setObjectName("label_3")
        self.verticalLayout_2.addWidget(self.label_3)
        self.lineEditYLabel = QtWidgets.QLineEdit(self.AxisParameters)
        self.lineEditYLabel.setObjectName("lineEditYLabel")
        self.verticalLayout_2.addWidget(self.lineEditYLabel)
        self.label_4 = QtWidgets.QLabel(self.AxisParameters)
        self.label_4.setObjectName("label_4")
        self.verticalLayout_2.addWidget(self.label_4)
        self.comboBoxAspect = QtWidgets.QComboBox(self.AxisParameters)
        self.comboBoxAspect.setObjectName("comboBoxAspect")
        self.comboBoxAspect.addItem("")
        self.comboBoxAspect.addItem("")
        self.verticalLayout_2.addWidget(self.comboBoxAspect)
        self.gridLayout_3.addLayout(self.verticalLayout_2, 0, 0, 1, 1)
        self.toolBox.addItem(self.AxisParameters, "")
        self.verticalLayout_5.addWidget(self.toolBox, 0, QtCore.Qt.AlignLeft)
        spacerItem5 = QtWidgets.QSpacerItem(20, 100, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Maximum)
        self.verticalLayout_5.addItem(spacerItem5)
        self.pushButtonDefaultView = QtWidgets.QPushButton(self.groupBox)
        self.pushButtonDefaultView.setMaximumSize(QtCore.QSize(200, 16777215))
        self.pushButtonDefaultView.setBaseSize(QtCore.QSize(200, 25))
        font = QtGui.QFont()
        font.setFamily("Arial")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.pushButtonDefaultView.setFont(font)
        self.pushButtonDefaultView.setObjectName("pushButtonDefaultView")
        self.verticalLayout_5.addWidget(self.pushButtonDefaultView)
        self.pushButtonClearAll = QtWidgets.QPushButton(self.groupBox)
        self.pushButtonClearAll.setMaximumSize(QtCore.QSize(200, 16777215))
        self.pushButtonClearAll.setBaseSize(QtCore.QSize(200, 0))
        font = QtGui.QFont()
        font.setFamily("Arial")
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.pushButtonClearAll.setFont(font)
        self.pushButtonClearAll.setObjectName("pushButtonClearAll")
        self.verticalLayout_5.addWidget(self.pushButtonClearAll)
        self.verticalLayout_5.setStretch(0, 10)
        self.verticalLayout_5.setStretch(1, 10)
        self.verticalLayout_5.setStretch(2, 10)
        self.verticalLayout_5.setStretch(3, 10)
        self.horizontalLayout_4.addWidget(self.groupBox)
        self.horizontalLayout_4.setStretch(1, 10)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1208, 22))
        self.menubar.setObjectName("menubar")
        self.menuFormat = QtWidgets.QMenu(self.menubar)
        self.menuFormat.setObjectName("menuFormat")
        self.menuFigure_Width_Format = QtWidgets.QMenu(self.menuFormat)
        self.menuFigure_Width_Format.setEnabled(False)
        self.menuFigure_Width_Format.setObjectName("menuFigure_Width_Format")
        self.menuFigure_Format_Settings = QtWidgets.QMenu(self.menuFormat)
        self.menuFigure_Format_Settings.setObjectName("menuFigure_Format_Settings")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionStyle = QtWidgets.QAction(MainWindow)
        self.actionStyle.setEnabled(False)
        self.actionStyle.setObjectName("actionStyle")
        self.actionSingle_Column = QtWidgets.QAction(MainWindow)
        self.actionSingle_Column.setEnabled(False)
        self.actionSingle_Column.setObjectName("actionSingle_Column")
        self.actionDouble_Column = QtWidgets.QAction(MainWindow)
        self.actionDouble_Column.setEnabled(False)
        self.actionDouble_Column.setObjectName("actionDouble_Column")
        self.actionJournal_Styles = QtWidgets.QAction(MainWindow)
        self.actionJournal_Styles.setEnabled(False)
        self.actionJournal_Styles.setObjectName("actionJournal_Styles")
        self.actionMacro_Schema = QtWidgets.QAction(MainWindow)
        self.actionMacro_Schema.setEnabled(False)
        self.actionMacro_Schema.setObjectName("actionMacro_Schema")
        self.actionExport_Lines_to_CSV = QtWidgets.QAction(MainWindow)
        self.actionExport_Lines_to_CSV.setVisible(False)
        self.actionExport_Lines_to_CSV.setObjectName("actionExport_Lines_to_CSV")
        self.actionExport_Bars_to_CSV = QtWidgets.QAction(MainWindow)
        self.actionExport_Bars_to_CSV.setVisible(False)
        self.actionExport_Bars_to_CSV.setObjectName("actionExport_Bars_to_CSV")
        self.actionExport_Fill_Between_to_CSV = QtWidgets.QAction(MainWindow)
        self.actionExport_Fill_Between_to_CSV.setVisible(False)
        self.actionExport_Fill_Between_to_CSV.setObjectName("actionExport_Fill_Between_to_CSV")
        self.actionExport_Image_to_CSV = QtWidgets.QAction(MainWindow)
        self.actionExport_Image_to_CSV.setVisible(False)
        self.actionExport_Image_to_CSV.setObjectName("actionExport_Image_to_CSV")
        self.actionFigureDPI = QtWidgets.QAction(MainWindow)
        self.actionFigureDPI.setObjectName("actionFigureDPI")
        self.actionFigureSavedDPI = QtWidgets.QAction(MainWindow)
        self.actionFigureSavedDPI.setObjectName("actionFigureSavedDPI")
        self.actionFigure_Size_Display = QtWidgets.QAction(MainWindow)
        self.actionFigure_Size_Display.setObjectName("actionFigure_Size_Display")
        self.actionFigure_Size_Saved = QtWidgets.QAction(MainWindow)
        self.actionFigure_Size_Saved.setObjectName("actionFigure_Size_Saved")
        self.menuFigure_Width_Format.addAction(self.actionSingle_Column)
        self.menuFigure_Width_Format.addAction(self.actionDouble_Column)
        self.menuFigure_Format_Settings.addAction(self.actionFigureDPI)
        self.menuFigure_Format_Settings.addAction(self.actionFigureSavedDPI)
        self.menuFigure_Format_Settings.addAction(self.actionFigure_Size_Display)
        self.menuFigure_Format_Settings.addAction(self.actionFigure_Size_Saved)
        self.menuFormat.addAction(self.actionStyle)
        self.menuFormat.addAction(self.menuFigure_Width_Format.menuAction())
        self.menuFormat.addSeparator()
        self.menuFormat.addAction(self.menuFigure_Format_Settings.menuAction())
        self.menuFormat.addSeparator()
        self.menuFormat.addAction(self.actionJournal_Styles)
        self.menuFormat.addAction(self.actionMacro_Schema)
        self.menuFile.addAction(self.actionExport_Lines_to_CSV)
        self.menuFile.addAction(self.actionExport_Bars_to_CSV)
        self.menuFile.addAction(self.actionExport_Fill_Between_to_CSV)
        self.menuFile.addAction(self.actionExport_Image_to_CSV)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuFormat.menuAction())

        self.retranslateUi(MainWindow)
        self.toolBox.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "SciPlot PyQt"))
        self.label_10.setText(_translate("MainWindow", "DPI: Saved"))
        self.label_9.setText(_translate("MainWindow", "DPI: Display"))
        self.label_11.setText(_translate("MainWindow", "Figure Size (inches)"))
        self.label_12.setText(_translate("MainWindow", "Width x Height"))
        self.pushButtonApplyFigParams.setText(_translate("MainWindow", "Apply New Parameters"))
        self.toolBox.setItemText(self.toolBox.indexOf(self.FigureParameters), _translate("MainWindow", "Figure Parameters"))
        self.label_5.setText(_translate("MainWindow", "Axis Visibility"))
        self.label_6.setText(_translate("MainWindow", "X Limits"))
        self.label_7.setText(_translate("MainWindow", "Y Limits"))
        self.label_8.setText(_translate("MainWindow", "Scaling"))
        self.comboBoxAxisScaling.setItemText(0, _translate("MainWindow", "auto"))
        self.comboBoxAxisScaling.setItemText(1, _translate("MainWindow", "equal"))
        self.comboBoxAxisScaling.setItemText(2, _translate("MainWindow", "tight"))
        self.comboBoxAxisScaling.setItemText(3, _translate("MainWindow", "image"))
        self.comboBoxAxisScaling.setItemText(4, _translate("MainWindow", "square"))
        self.label.setText(_translate("MainWindow", "Title"))
        self.label_2.setText(_translate("MainWindow", "X Label"))
        self.label_3.setText(_translate("MainWindow", "Y Label"))
        self.label_4.setText(_translate("MainWindow", "Aspect Ratio"))
        self.comboBoxAspect.setItemText(0, _translate("MainWindow", "auto"))
        self.comboBoxAspect.setItemText(1, _translate("MainWindow", "equal"))
        self.toolBox.setItemText(self.toolBox.indexOf(self.AxisParameters), _translate("MainWindow", "Axis Parameters"))
        self.pushButtonDefaultView.setText(_translate("MainWindow", "Set Default View"))
        self.pushButtonClearAll.setText(_translate("MainWindow", "Clear All"))
        self.menuFormat.setTitle(_translate("MainWindow", "Format"))
        self.menuFigure_Width_Format.setTitle(_translate("MainWindow", "Figure Width Format"))
        self.menuFigure_Format_Settings.setTitle(_translate("MainWindow", "Figure Format Settings"))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.actionStyle.setText(_translate("MainWindow", "Color Scheme"))
        self.actionSingle_Column.setText(_translate("MainWindow", "Single-Column"))
        self.actionDouble_Column.setText(_translate("MainWindow", "Double-Column"))
        self.actionJournal_Styles.setText(_translate("MainWindow", "Journal Styles"))
        self.actionMacro_Schema.setText(_translate("MainWindow", "Macro Schema"))
        self.actionExport_Lines_to_CSV.setText(_translate("MainWindow", "Export Lines to CSV"))
        self.actionExport_Bars_to_CSV.setText(_translate("MainWindow", "Export Bars to CSV"))
        self.actionExport_Fill_Between_to_CSV.setText(_translate("MainWindow", "Export Fill Between to CSV"))
        self.actionExport_Image_to_CSV.setText(_translate("MainWindow", "Export Image to CSV"))
        self.actionFigureDPI.setText(_translate("MainWindow", "DPI: Display"))
        self.actionFigureSavedDPI.setText(_translate("MainWindow", "DPI: Saved"))
        self.actionFigure_Size_Display.setText(_translate("MainWindow", "Figure Size: Display"))
        self.actionFigure_Size_Saved.setText(_translate("MainWindow", "Figure Size: Saved"))


